==> cxf-testutils-2.0.3.1-fuse-sources.jar: org/apache/type_test/xml/TestOccuringStruct2Response.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types3.OccuringStruct2;


/**
 * <p>Java class for testOccuringStruct2Response element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testOccuringStruct2Response">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="return" type="{http://apache.org/type_test/types3}OccuringStruct2"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types3}OccuringStruct2"/>
 *           &lt;element name="z" type="{http://apache.org/type_test/types3}OccuringStruct2"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_return",
    "y",
    "z"
})
@XmlRootElement(name = "testOccuringStruct2Response")
public class TestOccuringStruct2Response {

    @XmlElement(name = "return", namespace = "http://apache.org/type_test/xml", required = true)
    protected OccuringStruct2 _return;
    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected OccuringStruct2 y;
    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected OccuringStruct2 z;

    /**
     * Gets the value of the return property.
     * 
     * @return
     *     possible object is
     *     {@link OccuringStruct2 }
     *     
     */
    public OccuringStruct2 getReturn() {
        return _return;
    }

    /**
     * Sets the value of the return property.
     * 
     * @param value
     *     allowed object is
     *     {@link OccuringStruct2 }
     *     
     */
    public void setReturn(OccuringStruct2 value) {
        this._return = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link OccuringStruct2 }
     *     
     */
    public OccuringStruct2 getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link OccuringStruct2 }
     *     
     */
    public void setY(OccuringStruct2 value) {
        this.y = value;
    }

    /**
     * Gets the value of the z property.
     * 
     * @return
     *     possible object is
     *     {@link OccuringStruct2 }
     *     
     */
    public OccuringStruct2 getZ() {
        return z;
    }

    /**
     * Sets the value of the z property.
     * 
     * @param value
     *     allowed object is
     *     {@link OccuringStruct2 }
     *     
     */
    public void setZ(OccuringStruct2 value) {
        this.z = value;
    }

}

==> cxf-testutils-2.1.3.13-fuse-sources.jar: org/apache/type_test/xml/TestOccuringStruct2Response.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types3.OccuringStruct2;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="return" type="{http://apache.org/type_test/types3}OccuringStruct2"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types3}OccuringStruct2"/>
 *         &lt;element name="z" type="{http://apache.org/type_test/types3}OccuringStruct2"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_return",
    "y",
    "z"
})
@XmlRootElement(name = "testOccuringStruct2Response")
public class TestOccuringStruct2Response {

    @XmlElement(name = "return", required = true)
    protected OccuringStruct2 _return;
    @XmlElement(required = true)
    protected OccuringStruct2 y;
    @XmlElement(required = true)
    protected OccuringStruct2 z;

    /**
     * Gets the value of the return property.
     * 
     * @return
     *     possible object is
     *     {@link OccuringStruct2 }
     *     
     */
    public OccuringStruct2 getReturn() {
        return _return;
    }

    /**
     * Sets the value of the return property.
     * 
     * @param value
     *     allowed object is
     *     {@link OccuringStruct2 }
     *     
     */
    public void setReturn(OccuringStruct2 value) {
        this._return = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link OccuringStruct2 }
     *     
     */
    public OccuringStruct2 getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link OccuringStruct2 }
     *     
     */
    public void setY(OccuringStruct2 value) {
        this.y = value;
    }

    /**
     * Gets the value of the z property.
     * 
     * @return
     *     possible object is
     *     {@link OccuringStruct2 }
     *     
     */
    public OccuringStruct2 getZ() {
        return z;
    }

    /**
     * Sets the value of the z property.
     * 
     * @param value
     *     allowed object is
     *     {@link OccuringStruct2 }
     *     
     */
    public void setZ(OccuringStruct2 value) {
        this.z = value;
    }

}
